@@ -1,5 +1,5 @@
 import re
-from typing import List
+from typing import List, Optional
 
 from .trie import Trie
 from .newmm import segment
@@ -8,7 +8,7 @@ DEFAULT_WORD_TOKENIZE_ENGINE = "newmm"
 
 def word_tokenize(
     text: str,
-    custom_dict: Trie = None,
+    custom_dict: Optional[Trie] = None,
     engine: str = DEFAULT_WORD_TOKENIZE_ENGINE,
     keep_whitespace: bool = True,
 ) -> List[str]:
@@ -17,7 +17,10 @@ def word_tokenize(
         return []
 
     segments = []
-    segments = segment(text, custom_dict)
+    if custom_dict:
+        segments = segment(text, custom_dict)
+    else:
+        segments = segment(text)
 
     if not keep_whitespace:
         segments = [token.strip(" ") for token in segments if token.strip(" ")]
